@@ -9,12 +9,14 @@
 ###############################################################################
 from everysk.api_resources.workspace import Workspace
 from everysk.api_resources.workflow import Workflow
-from everysk.api_resources.execution import Execution
+from everysk.api_resources.workflow_execution import WorkflowExecution
 from everysk.api_resources.portfolio import Portfolio
 from everysk.api_resources.report import Report
 from everysk.api_resources.report_template import ReportTemplate
 from everysk.api_resources.datastore import Datastore
+from everysk.api_resources.file import File
 from everysk.api_resources.custom_index import CustomIndex
 from everysk.api_resources.calculation import Calculation
 from everysk.api_resources.market_data import MarketData
 from everysk.api_resources.parser import Parser
+
